@@ -619,6 +619,7 @@ class AalenAdditiveFitter(BaseFitter):
 
         # so this is a problem line. bfill performs a recursion which is
         # really not scalable. Plus even for modest datasets, this eats a lot of memory.
+        # Plus is bfill the correct thing to choose? It's forward looking...
         wp = df.to_panel().bfill().fillna(0)
 
         # initialize dataframe to store estimates
@@ -746,7 +747,7 @@ class AalenAdditiveFitter(BaseFitter):
         Returns the median lifetimes for the individuals.
         http://stats.stackexchange.com/questions/102986/percentile-loss-functions
         """
-        return qth_survival_times(0.5, self.predict_survival_function(X))
+        return qth_survival_times(p, self.predict_survival_function(X))[p]
 
     def predict_median(self, X):
         """
@@ -760,7 +761,7 @@ class AalenAdditiveFitter(BaseFitter):
         Compute the expected lifetime, E[T], using covarites X.
         """
         t = self.cumulative_hazards_.index
-        return trapz(self.predict_survival_function(X).values.T, t)
+        return pd.Series(trapz(self.predict_survival_function(X).values.T, t))
 
 
 class CoxPHFitter(BaseFitter):
@@ -1086,7 +1087,7 @@ class CoxPHFitter(BaseFitter):
         Compute the expected lifetime, E[T], using covarites X.
         """
         v = self.predict_survival_function(X)
-        return trapz(v.values.T, v.index)
+        return pd.Series(trapz(v.values.T, v.index))
 
     def _compute_baseline_hazard(self):
         # http://courses.nus.edu.sg/course/stacar/internet/st3242/handouts/notes3.pdf
@@ -1231,6 +1232,7 @@ def qth_survival_times(q, survival_functions):
 
     """
     q = pd.Series(q)
+    assert (q <= 1).all() and (0 <= q).all(), 'q must be between 0 and 1'
     survival_functions = pd.DataFrame(survival_functions)
     if survival_functions.shape[1] == 1 and q.shape == (1,):
         return survival_functions.apply(lambda s: qth_survival_time(q[0], s)).ix[0]
